@@ -17,7 +17,7 @@ DEFAULTS = {
     'AUTO_GENERATE_TASKS_DJANGO_COMMANDS': {},
     'AUTO_GENERATE_TASKS_BASE': 'django_celery_extensions.task.DjangoTask',
     'AUTO_GENERATE_TASKS_DEFAULT_CELERY_KWARGS': None,
-    'AUTO_SQS_MESSAGE_GROUP_ID_FROM_TASK_NAME': False,
+    'AUTO_SQS_MESSAGE_GROUP_ID': False,
 }
 
 
